@@ -12,7 +12,7 @@ NumericalDictionary: dict = {
 }
 
 
-def absolute_value(number: int):
+def absolute_value(number):
     """
     获取到一个数值的绝对值
     :param number: 需要被转换成为绝对值的数值
@@ -27,7 +27,7 @@ def tenfold(number: int) -> int:
     :param number: 需要被做十倍乘法的数值
     :return: 数值 * 10
     """
-    return ((number << 2) << 1) + (number << 1)
+    return (number << 3) + (number << 1)
 
 
 def divide_ten(number: int) -> float:
@@ -84,12 +84,12 @@ def calculation(calculation_char: str, an: float, bn: float) -> float:
         return an % bn
     else:
         raise AbnormalOperation(
-            "操作数计算异常，您的计算模式不存在，错误的计算模式 = [" + calculation_char + "]\n"
-                                                                                        "Operand calculation "
-                                                                                        "exception. Your calculation "
-                                                                                        "mode does not exist. Wrong "
-                                                                                        "calculation mode "
-                                                                                        "= [" + calculation_char + "]")
+            "操作数计算异常，您的计算模式不存在，错误的计算模式 = [" + calculation_char +
+            "]\nOperand calculation "
+            "exception. Your calculation "
+            "mode does not exist. Wrong "
+            "calculation mode "
+            "= [" + calculation_char + "]")
 
 
 def comparison_operation(calculation_char: str, left: float, right: float) -> bool:
@@ -117,3 +117,45 @@ def comparison_operation(calculation_char: str, left: float, right: float) -> bo
         raise AbnormalOperation("无法进行比较运算，因为有错误的运算符。\n"
                                 "The comparison operation cannot be performed because there is an incorrect operator.\n"
                                 "Bad comparison operator => " + calculation_char)
+
+
+def sum_of_range(start: float, end: float, step=1) -> float:
+    """
+    计算一个区间内所有数值的累加结果数值
+    :param step: 累加区间的区间元素步长
+    :param start: 区间的左起始区间
+    :param end: 区间的右终止区间
+    :return: 区间内所有数值的累加数值结果
+    """
+    if start == end:
+        return start
+    if step == 1:
+        if float == int(end) and start == int(start):
+            return float(int((start + end) * (absolute_value(end - start) + 1)) >> 1)
+        else:
+            return ((start + end) * (absolute_value(int(end) - int(start)) + 1)) / 2
+    else:
+        abs_value = absolute_value(end - start)
+        end -= abs_value % step
+        abs_value = absolute_value(end - start)
+        n = 1 + (abs_value / step)
+        return n * start + n * (n - 1) * (max(step, 2)) / 2
+
+
+def multiply_of_range(start: float, end: float, step: float):
+    """
+    计算一个区间内所有数值的累乘结果数值
+    :param start: 区间内左起始区间
+    :param end: 区间内右终止区间
+    :param step: 区间内元素之间的步长
+    :return: 区间内所有数值的累乘结果数值
+    """
+    if start == end:
+        return start
+    else:
+        res: float = start
+        temp = start + step
+        while temp <= end:
+            res *= temp
+            temp += step
+        return res
